==> haskell-colourista-0.1.0.1-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.1
visibility:           public
id:                   colourista-0.1.0.1-A3oK2rmWAqjF33fGo5QuhZ
key:                  colourista-0.1.0.1-A3oK2rmWAqjF33fGo5QuhZ
license:              MPL-2.0
copyright:            2020-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  3a535b64de701ae7e564d1eddaa83bed
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.0.1/site-local/colourista-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/colourista-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/colourista-0.1.0.1
hs-libraries:         HScolourista-0.1.0.1-A3oK2rmWAqjF33fGo5QuhZ
depends:
    ansi-terminal-0.11-C9raGJmrRpQ318ixPrYCyd base-4.15.0.0
    bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-colourista-0.1.0.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-colourista.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 colourista
version:              0.1.0.1
visibility:           public
id:                   colourista-0.1.0.1-6MlfKEeFRRhJqik63WAynL
key:                  colourista-0.1.0.1-6MlfKEeFRRhJqik63WAynL
license:              MPL-2.0
copyright:            2020-2021 Kowainik
maintainer:           Kowainik <xrom.xkov@gmail.com>
author:               Veronika Romashkina, Dmitrii Kovanikov
homepage:             https://github.com/kowainik/colourista
synopsis:             Convenient interface for printing colourful messages
description:
    Convenient interface for printing colourful messages based on the @ansi-terminal@ library.

category:             Terminal, ANSI
abi:                  1d7ed7090234646711de38c2c39ffd25
exposed:              True
exposed-modules:
    Colourista Colourista.IO Colourista.Pure Colourista.Short

import-dirs:          /usr/lib/ghc-9.0.1/site-local/colourista-0.1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/colourista-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/colourista-0.1.0.1
hs-libraries:         HScolourista-0.1.0.1-6MlfKEeFRRhJqik63WAynL
depends:
    ansi-terminal-0.11-FDn5stAeTja6b4Fn65mtJG base-4.15.0.0
    bytestring-0.10.12.1 ghc-prim-0.7.0 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-colourista/html/colourista.haddock
haddock-html:         /usr/share/doc/haskell-colourista/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
